<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk">
<context>
    <name>AddLayer</name>
    <message>
        <location filename="../AddLayer.js" line="+35"/>
        <source>Layer</source>
        <translation>Vrstva</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Add Layer</source>
        <translation>Pridať vrstvu</translation>
    </message>
    <message>
        <location filename="../AddLayerInit.js" line="+2"/>
        <source>&amp;Add Layer</source>
        <translation>Prid&amp;ať vrstvu</translation>
    </message>
</context>
<context>
    <name>Layer</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+33"/>
        <source>Default color for new layers:</source>
        <translation>Predvolená farba pre nové vrstvy:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Default lineweight for layer 0:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Default color for layer 0:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-45"/>
        <source>Default lineweight for new layers:</source>
        <translation>Predvolená hrúbka čiary pre novú vrstvu:</translation>
    </message>
</context>
</TS>
